Package 'jds.rmd'

Title: R Markdown Templates for Journal of Data Science
Description: Customized R Markdown templates for authoring articles for Journal of Data Science.
Authors: Wenjie Wang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0363-3180>), Jun Yan [aut] (ORCID: <https://orcid.org/0000-0003-4401-7296>)
Maintainer: Wenjie Wang <[email protected]>
License: GPL (>= 3)
Version: 0.3.4
Built: 2026-05-14 09:04:17 UTC
Source: https://github.com/wenjie2wang/jds.rmd

Help Index


Creat A Draft of JDS Article

Description

Create a JDS article draft using the specified LaTeX class file. This function is a simplified version of 'rmarkdown::draft()' for creating a JDS article draft only.

Usage

draft(file, cls = c("jdsart", "jds"))

Arguments

file

A character string for the file name of the draft. Different with rmarkdown::draft(), the suffix ".Rmd" will not be added if it is not specified.

cls

The LaTeX class name. The available choices are jdsart for the latest class developed by vtex, or jds for the deprecated class.

Value

The file name of the new document (invisibly).

Examples

if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) {
    ## draft from a sample R markdown file
    jds.rmd::draft("jds-sample.Rmd")
    ## produce pdf with the tex source kept for submission
    rmarkdown::render("jds-sample.Rmd")
}

PDF Article for Journal of Data Science

Description

Provides output format to render PDF article for submission to Journal of Data Science.

Usage

pdf_article(..., cls = c("jdsart", "jds"))

Arguments

...

Optional named arguments passed to bookdown::pdf_book() and rmarkdown::pdf_document() other than base_format.

cls

The LaTeX class name. The available choices are jdsart for the latest class developed by vtex, or jds for the deprecated class.

Value

The output format that can only be used with bookdown::render_book().

Examples

if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) {
    ## draft from a sample R markdown file
    jds.rmd::draft("jds-sample.Rmd")
    ## produce pdf with the tex source kept for submission
    rmarkdown::render("jds-sample.Rmd")
}