| Title: | R Markdown Templates for Journal of Data Science |
|---|---|
| Description: | Customized R Markdown templates for authoring articles for Journal of Data Science. |
| Authors: | Wenjie Wang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0363-3180>), Jun Yan [aut] (ORCID: <https://orcid.org/0000-0003-4401-7296>) |
| Maintainer: | Wenjie Wang <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.3.4 |
| Built: | 2026-05-14 09:04:17 UTC |
| Source: | https://github.com/wenjie2wang/jds.rmd |
Create a JDS article draft using the specified LaTeX class file. This function is a simplified version of 'rmarkdown::draft()' for creating a JDS article draft only.
draft(file, cls = c("jdsart", "jds"))draft(file, cls = c("jdsart", "jds"))
file |
A character string for the file name of the draft. Different
with |
cls |
The LaTeX class name. The available choices are |
The file name of the new document (invisibly).
if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) { ## draft from a sample R markdown file jds.rmd::draft("jds-sample.Rmd") ## produce pdf with the tex source kept for submission rmarkdown::render("jds-sample.Rmd") }if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) { ## draft from a sample R markdown file jds.rmd::draft("jds-sample.Rmd") ## produce pdf with the tex source kept for submission rmarkdown::render("jds-sample.Rmd") }
Provides output format to render PDF article for submission to Journal of Data Science.
pdf_article(..., cls = c("jdsart", "jds"))pdf_article(..., cls = c("jdsart", "jds"))
... |
Optional named arguments passed to |
cls |
The LaTeX class name. The available choices are |
The output format that can only be used with
bookdown::render_book().
if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) { ## draft from a sample R markdown file jds.rmd::draft("jds-sample.Rmd") ## produce pdf with the tex source kept for submission rmarkdown::render("jds-sample.Rmd") }if (interactive() && requireNamespace("rmarkdown", quietly = TRUE)) { ## draft from a sample R markdown file jds.rmd::draft("jds-sample.Rmd") ## produce pdf with the tex source kept for submission rmarkdown::render("jds-sample.Rmd") }